from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, File

Draw_V0_1_0 = CommandToolBuilder(tool="draw", base_command=["draw"], inputs=[ToolInput(tag="in_circle", input_type=Boolean(optional=True), prefix="--circle", doc=InputDocumentation(doc="Specify that the structure should be drawn with its backbone stretched\naround a circle. Note that pseudoknotted structures will be drawn\ncircularized even if this option is not specified.\nDefault is to show a collapsed structure.")), ToolInput(tag="in_flat", input_type=Boolean(optional=True), prefix="--flat", doc=InputDocumentation(doc="Specify that the structure should be drawn with its backbone stretched in a\nstraight line.\nDefault is to show a collapsed structure.")), ToolInput(tag="in_levo_rotatory", input_type=Boolean(optional=True), prefix="--levorotatory", doc=InputDocumentation(doc="Specify that the drawn structure is rendered counterclockwise.\nDefault is to render drawn structures clockwise.")), ToolInput(tag="in_svg", input_type=Boolean(optional=True), prefix="--svg", doc=InputDocumentation(doc="Specify that the output file should be an SVG image file, rather than a\nPostscript image file. Note that only one SVG image can be written into a\nparticular file, so the structure number flag must also be specified when\nwriting an SVG document.")), ToolInput(tag="in_uncircled", input_type=Boolean(optional=True), prefix="--uncircled", doc=InputDocumentation(doc="Specify that no circles should surround nucleotides when drawing.\nDefault is to surround nucleotides with circles.")), ToolInput(tag="in_desc", input_type=File(optional=True), prefix="--desc", doc=InputDocumentation(doc="Configure the output of descriptions. Valid values are: (1) '' or '~none'\n-- Do not write a description (2) '~file' -- If the default description\ncorresponds to a file or path, use only the base name of the path (i.e. no\ndirectory or file extension). (3) '~~' or '~default' -- Use the default\ndescription (this is the same as not specifying the flag) (4)\n'~list|DESC1|DESC2|DESC3' -- use this syntax when the output is expected to\nhave more than one plot. It specifies a list of descriptions will be\napplied in the order given. The character immediately after '~list' will be\nused as the separator. (5) Any other value is assumed to be the literal\ndescription you want to have displayed in the plot legend.")), ToolInput(tag="in_end", input_type=Boolean(optional=True), prefix="--end", doc=InputDocumentation(doc="Specify the ending structure number. Use this in combination with the\n--number (-n) flag to specify a range of structures to draw, e.g.\n'--number 3 --end 7' to draw structures 3 through 7.")), ToolInput(tag="in_loop_probability", input_type=Boolean(optional=True), prefix="--loopprobability", doc=InputDocumentation(doc="Specify the name of the partition function file from which loop probability\ndata will be read for annotation. This file should describe pairing data\nfor the predicted structure, not the accepted structure.\nDefault is no probability annotation file used.")), ToolInput(tag="in_max_structures", input_type=Boolean(optional=True), prefix="--maxstructures", doc=InputDocumentation(doc="Limit the total number of structures drawn. This is useful in automated\ntool chains to prevent creation of huge output files when many results are\nreturned from another program (e.g. AllSub).")), ToolInput(tag="in_number", input_type=File(optional=True), prefix="--number", doc=InputDocumentation(doc="Specify the index of a particular structure in the predicted CT to be\ncompared with the accepted CT, one-indexed.\nDefault is -1, which signifies all structures output to one file.")), ToolInput(tag="in_probability", input_type=Boolean(optional=True), prefix="--probability", doc=InputDocumentation(doc="Specify the name of the partition function file from which base pairing\nprobability data will be read for annotation. This file should describe\npairing data for the predicted structure, not the accepted structure.\nDefault is no probability annotation file used.")), ToolInput(tag="in_shape", input_type=Boolean(optional=True), prefix="--SHAPE", doc=InputDocumentation(doc="Specify the name of the file from which SHAPE data will be read for\nannotation.\nDefault is no SHAPE annotation file used.")), ToolInput(tag="in_text", input_type=Boolean(optional=True), prefix="--text", doc=InputDocumentation(doc="Specify the name of the text file from which base pairing probability data\nwill be read for annotation. This file should describe pairing data for the\npredicted structure, not the accepted structure.\nDefault is no probability annotation file used.\n")), ToolInput(tag="in_ct_file", input_type=File(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_output_file", input_type=File(), position=1, doc=InputDocumentation(doc=""))], outputs=[ToolOutput(tag="out_desc", output_type=File(optional=True), selector=InputSelector(input_to_select="in_desc", type_hint=File()), doc=OutputDocumentation(doc="Configure the output of descriptions. Valid values are: (1) '' or '~none'\n-- Do not write a description (2) '~file' -- If the default description\ncorresponds to a file or path, use only the base name of the path (i.e. no\ndirectory or file extension). (3) '~~' or '~default' -- Use the default\ndescription (this is the same as not specifying the flag) (4)\n'~list|DESC1|DESC2|DESC3' -- use this syntax when the output is expected to\nhave more than one plot. It specifies a list of descriptions will be\napplied in the order given. The character immediately after '~list' will be\nused as the separator. (5) Any other value is assumed to be the literal\ndescription you want to have displayed in the plot legend.")), ToolOutput(tag="out_number", output_type=File(optional=True), selector=InputSelector(input_to_select="in_number", type_hint=File()), doc=OutputDocumentation(doc="Specify the index of a particular structure in the predicted CT to be\ncompared with the accepted CT, one-indexed.\nDefault is -1, which signifies all structures output to one file.")), ToolOutput(tag="out_output_file", output_type=File(), selector=InputSelector(input_to_select="in_output_file", type_hint=File()), doc=OutputDocumentation(doc=""))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Draw_V0_1_0().translate("wdl", allow_empty_container=True)

